@@ -62,7 +62,7 @@
 #define SUPERNOVAS_MAJOR_VERSION  1
 
 /// API minor version
-#define SUPERNOVAS_MINOR_VERSION  3
+#define SUPERNOVAS_MINOR_VERSION  4
 
 /// Integer sub version of the release
 #define SUPERNOVAS_PATCHLEVEL     0
@@ -218,6 +218,11 @@
 /// @since 1.3
 #define NOVAS_SYSTEM_HIP           "HIP"
 
+/// [&mu;m] Default wavelength, e.g. for wavelength-dependent refraction models. It is set to the
+/// median wavelength of visible light.
+/// @since 1.4
+#define NOVAS_DEFAULT_WAVELENGTH      0.55
+
 #if !COMPAT
 // If we are not in the strict compatibility mode, where constants are defined
 // as variables in novascon.h (with implementation in novascon.c), then define
@@ -348,14 +353,25 @@ enum novas_planet {
  * [9]: Pluto (barycenter), [10]: Sun, [11]: Moon.
  * Barycentric reciprocal masses (index 12, 13) are not set.
  *
+ * NOTES:
+ * <ol>
+ * <li>The values have been updated to used DE440 data (Park et al. 2021) in 1.4.
+ * </ol>
+ *
+ * REFERENCES:
+ * <ol>
+ * <li>Ryan S. Park et al 2021 AJ 161 105, DOI 10.3847/1538-3881/abd414</li>
+ * </ol>
+ *
  * @sa enum novas_planet
  * @sa NOVAS_PLANETS
  * @since 1.2
  * @author Attila Kovacs
  */
 #define NOVAS_RMASS_INIT  { \
-      328900.561400, 6023600.0, 408523.71, 332946.050895, 3098708.0, 1047.3486, 3497.898, \
-      22902.98, 19412.24, 135200000.0, 1.0, 27068700.387534, 0.0, 0.0 }
+      328900.559708565, 6023657.9450387, 408523.718656268, 332946.048773067, 3098703.54671961, \
+      1047.348631244, 3497.9018007932, 22902.9507834766, 19412.2597758766, 136045556.16738, \
+      1.0, 27068702.9548773, 0.0, 0.0 }
 
 /**
  * Gravitational redshifts for major planets (and Moon and Sun) for light emitted at surface
@@ -421,9 +437,7 @@ enum novas_reference_system {
   NOVAS_GCRS = 0,
 
   /// True equinox Of Date: dynamical system of the 'true' equator, with its origin at the
-  /// 'true' equinox (pre IAU 2006 system). It is inherently less precise than the new standard
-  /// CIRS because mainly because it is based on separate, and less-precise, precession
-  /// and nutation models (Lieske et. al. 1977).
+  /// 'true' equinox (pre IAU 2006 system).
   NOVAS_TOD,
 
   /// Celestial Intermediate Reference System: dynamical system of the true equator, with its
@@ -440,9 +454,21 @@ enum novas_reference_system {
 
   /// Mean equinox of date:  dynamical system of the 'mean' equator, with its origin at the
   /// 'mean' equinox (pre IAU 2006 system). It includes precession (Lieske et. al. 1977),
-  /// but no nutation.
+  /// but no nutation. For example, FK4 / B1950 is a MOD coordinate system.
   /// @since 1.1
   NOVAS_MOD,
+
+  /// Terrestrial Intermediate Reference System. It is the IAU 2006 standard pseudo Earth-fixed
+  /// (PEF) coordinate system, which co-rotates with Earth, but does not include Earth polar
+  /// wobble corrections.
+  /// @since 1.4
+  NOVAS_TIRS,
+
+  /// International Terrestrial Reference System. This is the IAU 2006 Earth-fixed reference
+  /// system, and includes small measured corrections for the unmodelled polar motion, as
+  /// published by the IERS Bulletins.
+  /// @since 1.4
+  NOVAS_ITRS
 };
 
 /**
@@ -450,7 +476,7 @@ enum novas_reference_system {
  *
  * @sa enum novas_reference_system
  */
-#define NOVAS_REFERENCE_SYSTEMS   (NOVAS_MOD + 1)
+#define NOVAS_REFERENCE_SYSTEMS   (NOVAS_ITRS + 1)
 
 /**
  * Constants that determine the type of equator to be used for the coordinate system.
@@ -458,9 +484,9 @@ enum novas_reference_system {
  * @sa NOVAS_EQUATOR_TYPES
  */
 enum novas_equator_type {
-  NOVAS_MEAN_EQUATOR = 0, ///< Mean equator of date without nutation (pre IAU 2006 system).
-  NOVAS_TRUE_EQUATOR,     ///< True equator of date (pre IAU 2006 system).
-  NOVAS_GCRS_EQUATOR      ///< Geocentric Celestial Reference System (GCRS).
+  NOVAS_MEAN_EQUATOR = 0, ///< Mean celestial equator of date without nutation (pre IAU 2006 system).
+  NOVAS_TRUE_EQUATOR,     ///< True celestial equator of date (pre IAU 2006 system).
+  NOVAS_GCRS_EQUATOR      ///< Geocentric Celestial Reference System (GCRS) equator.
 };
 
 /**
@@ -503,11 +529,11 @@ enum novas_accuracy {
 };
 
 /**
- * Constants that determine whether refraction calculations should use a standard atmospheric
- * model, or whatever weather parameters have been been specified for the observing location.
+ * Constants that determine whether what model (if any) to use for implicit refraction calculations.
  *
  * @sa on_surface
  * @sa refract()
+ * @sa refract_astro()
  */
 enum novas_refraction_model {
   /// Do not apply atmospheric refraction correction
@@ -518,9 +544,28 @@ enum novas_refraction_model {
   NOVAS_STANDARD_ATMOSPHERE,
 
   /// Uses the weather parameters that are specified together with the observing location.
-  NOVAS_WEATHER_AT_LOCATION
+  NOVAS_WEATHER_AT_LOCATION,
+
+  /// Uses the Berman &amp; Rockwell 1976 refraction model for Radio wavelengths with the
+  /// weather parameters specified together with the observing location.
+  /// @since 1.4
+  NOVAS_RADIO_REFRACTION,
+
+  /// Uses the IAU / SOFA wavelength-depended refraction model with the weather parameters
+  /// specified together with the observing location. The wavelength can be  specified
+  /// via `novas_refract_wavelength()` or else it is assumed to be 550 nm (visible light).
+  /// @sa novas_refract_wavelength()
+  /// @since 1.4
+  NOVAS_WAVE_REFRACTION
 };
 
+/**
+ * The number of built-in refraction models available in SuperNOVAS.
+ *
+ * @sa enum novas_refraction_model
+ */
+#define NOVAS_REFRACTION_MODELS   (NOVAS_WAVE_REFRACTION + 1)
+
 /**
  * Constants that determine the type of rotation measure to use.
  */
@@ -649,18 +694,36 @@ enum novas_cio_location_type {
  * Direction constants for polar wobble corrections via the wobble() function.
  *
  * @sa wobble()
- * @sa WOBBLE_ITRS_TO_TIRS
+ * @sa NOVAS_WOBBLE_DIRECTIONS
  */
 enum novas_wobble_direction {
-  /// use for wobble() to change from ITRS (actual rotating Earth) to Pseudo Earth Fixed (PEF) /
-  /// TIRS.
-  WOBBLE_ITRS_TO_PEF = 0,
+  /// use for wobble() to change from ITRS (Earth-fixed) to TIRS (pseudo Earth-fixed). It includes TIO
+  /// longitude correction.
+  /// @since 1.4
+  WOBBLE_ITRS_TO_TIRS = 0,
 
-  /// use for wobble() to change from Pseudo Earth Fixed (PEF) / TIRS to ITRS (actual rotating
-  /// Earth).
+  /// use for wobble() to change from TIRS (pseudo Earth-fixed) to ITRS (Earth-fixed). It includes TIO
+  /// longitude correction.
+  /// @since 1.4
+  WOBBLE_TIRS_TO_ITRS,
+
+  /// use for wobble() to change from ITRS (Earth-fixed) Pseudo Earth Fixed (PEF). It does not include
+  /// TIO longitude correction. Otherwise, it's the same as WOBBLE_ITRS_TO_TIRS
+  WOBBLE_ITRS_TO_PEF,
+
+  /// use for wobble() to change from Pseudo Earth Fixed (PEF) to ITRS (Earth-fixed). It does not
+  /// include TIO longitude correction. Otherwise, it's the same as WOBBLE_TIRS_TO_ITRS
   WOBBLE_PEF_TO_ITRS
 };
 
+/**
+ * Number of values in enum novas_wobble_direction
+ *
+ * @since 1.4
+ * @sa novas_wobble_direction
+ */
+#define NOVAS_WOBBLE_DIRECTIONS     (WOBBLE_PEF_TO_ITRS + 1)
+
 /**
  * Direction constant to use for frame_tie(), to determine the direction of transformation
  * between J2000 and ICRS coordinates.
@@ -709,7 +772,7 @@ enum novas_reference_plane {
  * @author Attila Kovacs
  * @sa NOVAS_DELAUNAY_ARGS_INIT
  */
-typedef struct {
+typedef struct novas_delaunay_args {
   double l;           ///< [rad] mean anomaly of the Moon
   double l1;          ///< [rad] mean anomaly of the Sun
   double F;           ///< [rad] mean argument of the latitude of the Moon
@@ -738,7 +801,7 @@ typedef struct {
  *
  * @sa CAT_ENTRY_INIT
  */
-typedef struct {
+typedef struct novas_cat_entry {
   char starname[SIZE_OF_OBJ_NAME];  ///< name of celestial object
   char catalog[SIZE_OF_CAT_NAME];   ///< catalog designator (e.g., HIP)
   long starnumber;                  ///< integer identifier assigned to object
@@ -784,10 +847,12 @@ typedef struct {
  * @sa novas_orbital
  * @sa NOVAS_ORBITAL_SYSTEM_INIT
  */
-typedef struct {
+typedef struct novas_orbital_system {
   enum novas_planet center;          ///< major planet or barycenter at the center of the orbit.
   enum novas_reference_plane plane;  ///< reference plane NOVAS_ECLIPTIC_PLANE or NOVAS_EQUATORIAL_PLANE
   enum novas_reference_system type;  ///< the coordinate reference system used for the reference plane and orbitals.
+                                     ///< It must be a system, which does not co-rotate with Earth (i.e. not ITRS or
+                                     ///< TIRS).
   double obl;                        ///< [rad] relative obliquity of orbital reference plane
                                      ///<       (e.g. 90&deg; - &delta;<sub>pole</sub>)
   double Omega;                      ///< [rad] relative argument of ascending node of the orbital reference plane
@@ -833,19 +898,19 @@ typedef struct {
  * @sa enum NOVAS_ORBITAL_OBJECT
  * @sa NOVAS_ORBIT_INIT
  */
-typedef struct {
-  novas_orbital_system system;      ///< orbital reference system assumed for the parametrization
-  double jd_tdb;                    ///< [day] Barycentri Dynamical Time (TDB) based Julian date of the parameters.
-  double a;                         ///< [AU] semi-major axis
-  double e;                         ///< eccentricity
-  double omega;                     ///< [deg] argument of periapsis / perihelion, at the reference time
-  double Omega;                     ///< [deg] argument of ascending node on the reference plane, at the reference time
-  double i;                         ///< [deg] inclination of orbit to the reference plane
-  double M0;                        ///< [deg] mean anomaly at the reference time
-  double n;                         ///< [deg/day] mean daily motion, i.e. (_GM_/_a_<sup>3</sup>)<sup>1/2</sup> for the central body,
-                                    ///< or 360/T, where T is orbital period in days.
-  double apsis_period;              ///< [day] Precession period of the apsis, if known.
-  double node_period;               ///< [day] Precession period of the ascending node, if known.
+typedef struct novas_orbital {
+  struct novas_orbital_system system; ///< orbital reference system assumed for the parametrization
+  double jd_tdb;                      ///< [day] Barycentri Dynamical Time (TDB) based Julian date of the parameters.
+  double a;                           ///< [AU] semi-major axis
+  double e;                           ///< eccentricity
+  double omega;                       ///< [deg] argument of periapsis / perihelion, at the reference time
+  double Omega;                       ///< [deg] argument of ascending node on the reference plane, at the reference time
+  double i;                           ///< [deg] inclination of orbit to the reference plane
+  double M0;                          ///< [deg] mean anomaly at the reference time
+  double n;                           ///< [deg/day] mean daily motion, i.e. (_GM_/_a_<sup>3</sup>)<sup>1/2</sup> for the central body,
+                                      ///< or 360/T, where T is orbital period in days.
+  double apsis_period;                ///< [day] Precession period of the apsis, if known.
+  double node_period;                 ///< [day] Precession period of the ascending node, if known.
 } novas_orbital;
 
 /**
@@ -879,12 +944,12 @@ typedef struct {
  * @sa NOVAS_MOON_INIT
  * @sa NOVAS_EMB_INIT
  */
-typedef struct {
+typedef struct novas_object {
   enum novas_object_type type;    ///< NOVAS object type
   long number;                    ///< enum novas_planet, or minor planet ID (e.g. NAIF), or star catalog ID.
   char name[SIZE_OF_OBJ_NAME];    ///< name of the object (0-terminated)
-  cat_entry star;                 ///< basic astrometric data for NOVAS_CATALOG_OBJECT type.
-  novas_orbital orbit;            ///< orbital data for NOVAS_ORBITAL_OBJECT type. @since 1.2
+  struct novas_cat_entry star;    ///< basic astrometric data (in ICRS) for NOVAS_CATALOG_OBJECT type.
+  struct novas_orbital orbit;     ///< orbital data for NOVAS_ORBITAL_OBJECT type. @since 1.2
 } object;
 
 /**
@@ -1013,7 +1078,7 @@ typedef struct {
  * @sa ON_SURFACE_INIT
  * @sa ON_SURFACE_LOC
  */
-typedef struct {
+typedef struct novas_on_surface {
   double latitude;      ///< [deg] geodetic (ITRS) latitude; north positive
   double longitude;     ///< [deg] geodetic (ITRS) longitude; east positive
   double height;        ///< [m] altitude above sea level
@@ -1053,7 +1118,7 @@ typedef struct {
  * @sa IN_SPACE_INIT
  * @sa make_in_space()
  */
-typedef struct {
+typedef struct novas_in_space {
   double sc_pos[3];     ///< [km] geocentric (or [AU] ICRS barycentric) position vector (x, y, z)
   double sc_vel[3];     ///< [km/s] geocentric (or [AU/day] ICRS barycentric) velocity vector (x_dot, y_dot, z_dot)
 } in_space;
@@ -1076,17 +1141,17 @@ typedef struct {
  * @sa make_solar_system_observer()
  * @sa OBSERVER_INIT
  */
-typedef struct {
+typedef struct novas_observer {
   enum novas_observer_place where;    ///< observer location type
 
   /// structure containing data for an observer's location on the surface of the Earth
   /// (if where = NOVAS_OBSERVER_ON_EARTH)
-  on_surface on_surf;
+  struct novas_on_surface on_surf;
 
   /// data for an observer's location in orbit (if where = NOVAS_OBSERVER_IN_EARTH_ORBIT)
   /// As of v1.1 the same structure may be used to store heliocentric location and motion
   /// for any Solar-system observer also (if where = NOVAS_SOLAR_SYSTEM_OBSERVER).
-  in_space near_earth;
+  struct novas_in_space near_earth;
 } observer;
 
 /**
@@ -1105,7 +1170,7 @@ typedef struct {
  * @sa SKY_POS_INIT
  * @sa novas_z_lsr()
  */
-typedef struct {
+typedef struct novas_sky_pos {
   double r_hat[3];  ///< unit vector toward object (dimensionless)
   double ra;        ///< [h] apparent, topocentric, or astrometric right ascension (hours)
   double dec;       ///< [deg] apparent, topocentric, or astrometric declination (degrees)
@@ -1127,7 +1192,7 @@ typedef struct {
  * Right ascension of the Celestial Intermediate Origin (CIO) with respect to the GCRS
  *
  */
-typedef struct {
+typedef struct novas_ra_of_cio {
   double jd_tdb;    ///< [day] Barycentric Dynamical Time (TDB) based Julian date.
   double ra_cio;    ///< [arcsec] right ascension of the CIO with respect to the GCRS (arcseconds)
 } ra_of_cio;
@@ -1170,7 +1235,7 @@ enum novas_timescale {
  * @since 1.1
  * @sa NOVAS_TIMESPEC_INIT
  */
-typedef struct {
+typedef struct novas_timespec {
   long ijd_tt;        ///< [day] Integer part of the Terrestrial Time (TT) based Julian Date
   double fjd_tt;      ///< [day] Terrestrial time (TT) based fractional Julian day.
   double tt2tdb;      ///< [s] TDB - TT time difference
@@ -1194,7 +1259,7 @@ typedef struct {
  * @sa NOVAS_MATRIX_INIT
  * @sa NOVAS_MATRIX_IDENTITY
  */
-typedef struct {
+typedef struct novas_matrix {
   double M[3][3];     ///< matrix elements
 } novas_matrix;
 
@@ -1224,7 +1289,7 @@ typedef struct {
  * @sa enum novas_planet
  * @sa NOVAS_PLANET_BUNDLE_INIT
  */
-typedef struct {
+typedef struct novas_planet_bundle {
   int mask;                      ///< Bitwise mask (1 << planet-number) specifying wich planets have pos/vel data
   double pos[NOVAS_PLANETS][3];  ///< [AU] Apparent positions of planets w.r.t. observer antedated for light-time
   double vel[NOVAS_PLANETS][3];  ///< [AU/day] Apparent velocity of planets w.r.t. barycenter antedated for light-time
@@ -1259,35 +1324,37 @@ typedef struct {
  * @sa novas_change_observer()
  * @sa NOVAS_FRAME_INIT
  */
-typedef struct {
-  uint64_t state;                 ///< An internal state for checking validity.
-  enum novas_accuracy accuracy;   ///< NOVAS_FULL_ACCURACY or NOVAS_REDUCED_ACCURACY
-  novas_timespec time;            ///< The instant of time for which this observing frame is valid
-  observer observer;              ///< The observer location, or NULL for barycentric
-  double mobl;                    ///< [rad] Mean obliquity
-  double tobl;                    ///< [rad] True obliquity
-  double ee;                      ///< [rad] Equation of the equinoxes
-  double dpsi0;                   ///< [rad] Modeled Earth orientation &psi; (not including polar wobble)
-  double deps0;                   ///< [rad] Modeled Earth orientation &epsilon; (not including polar wobble)
-  double dx;                      ///< [mas] Polar wobble parameter dx.
-  double dy;                      ///< [mas] Polar wobble parameter dy.
-  double era;                     ///< [deg] Earth Rotation Angle (ERA);
-  double gst;                     ///< [h] Greenwich (Apparent) Sidereal Time (GST / GAST)
-  double obs_pos[3];              ///< [AU] Observer position rel. to barycenter (ICRS)
-  double obs_vel[3];              ///< [AU/day] Observer movement rel. to barycenter (ICRS)
-  double v_obs;                   ///< [AU/day] Magnitude of observer motion rel. to barycenter
-  double beta;                    ///< Observer relativistic &beta; rel SSB
-  double gamma;                   ///< Observer Lorentz factor &Gamma; rel SSB
-  double sun_pos[3];              ///< [AU] Sun's geometric position, rel SSB. (ICRS)
-  double sun_vel[3];              ///< [AU/day] Sun's velocity, rel SSB. (ICRS)
-  double earth_pos[3];            ///< [AU] Earth's geometric position, rel SSB. (ICRS)
-  double earth_vel[3];            ///< [AU/day] Earth's velocity, rel SSB. (ICRS)
-  novas_matrix icrs_to_j2000;     ///< ICRS to J2000 matrix
-  novas_matrix precession;        ///< precession matrix
-  novas_matrix nutation;          ///< nutation matrix (Lieske 1977 method)
-  novas_matrix gcrs_to_cirs;      ///< GCRS to CIRS conversion matrix
-  novas_planet_bundle planets;    ///< Planet positions and velocities (ICRS)
+typedef struct novas_frame {
+  uint64_t state;                     ///< An internal state for checking validity.
+  enum novas_accuracy accuracy;       ///< NOVAS_FULL_ACCURACY or NOVAS_REDUCED_ACCURACY
+  struct novas_timespec time;         ///< The instant of time for which this observing frame is valid
+  struct novas_observer observer;     ///< The observer location, or NULL for barycentric
+  double mobl;                        ///< [rad] Mean obliquity
+  double tobl;                        ///< [rad] True obliquity
+  double ee;                          ///< [rad] Equation of the equinoxes
+  double dpsi0;                       ///< [rad] Modeled Earth orientation &psi; (not including polar wobble)
+  double deps0;                       ///< [rad] Modeled Earth orientation &epsilon; (not including polar wobble)
+  double dx;                          ///< [mas] Polar wobble parameter dx.
+  double dy;                          ///< [mas] Polar wobble parameter dy.
+  double era;                         ///< [deg] Earth Rotation Angle (ERA);
+  double gst;                         ///< [h] Greenwich (Apparent) Sidereal Time (GST / GAST)
+  double obs_pos[3];                  ///< [AU] Observer position rel. to barycenter (ICRS)
+  double obs_vel[3];                  ///< [AU/day] Observer movement rel. to barycenter (ICRS)
+  double v_obs;                       ///< [AU/day] Magnitude of observer motion rel. to barycenter
+  double beta;                        ///< Observer relativistic &beta; rel SSB
+  double gamma;                       ///< Observer Lorentz factor &Gamma; rel SSB
+  double sun_pos[3];                  ///< [AU] Sun's geometric position, rel SSB. (ICRS)
+  double sun_vel[3];                  ///< [AU/day] Sun's velocity, rel SSB. (ICRS)
+  double earth_pos[3];                ///< [AU] Earth's geometric position, rel SSB. (ICRS)
+  double earth_vel[3];                ///< [AU/day] Earth's velocity, rel SSB. (ICRS)
+  struct novas_matrix icrs_to_j2000;  ///< ICRS to J2000 matrix
+  struct novas_matrix precession;     ///< precession matrix
+  struct novas_matrix nutation;       ///< nutation matrix (Lieske 1977 method)
+  struct novas_matrix gcrs_to_cirs;   ///< GCRS to CIRS conversion matrix
+  struct novas_planet_bundle planets; ///< Planet positions and velocities (ICRS)
   // TODO [v2] add ra_cio
+  // TODO [v2] add cirs_to_tirs
+  // TODI [v2] add tirs_to_itrs
 } novas_frame;
 
 /**
@@ -1314,11 +1381,11 @@ typedef struct {
  * @sa novas_invert_transform()
  * @sa NOVAS_TRANSFORM_INIT
  */
-typedef struct {
+typedef struct novas_transform {
   enum novas_reference_system from_system;  ///< The original coordinate system
   enum novas_reference_system to_system;    ///< The final coordinate system
-  novas_frame frame;                        ///< The observer place and time for which the transform is valid
-  novas_matrix matrix;                      ///< Transformation matrix elements
+  struct novas_frame frame;                 ///< The observer place and time for which the transform is valid
+  struct novas_matrix matrix;               ///< Transformation matrix elements
 } novas_transform;
 
 /**
@@ -1419,7 +1486,7 @@ typedef double (*RefractionModel)(double jd_tt, const on_surface *loc, enum nova
  * @sa novas_track
  * @sa NOVAS_OBSERVABLE_INIT
  */
-typedef struct {
+typedef struct novas_observable {
   double lon;           ///< [deg] apparent longitude coordinate in coordinate system
   double lat;           ///< [deg] apparent latitude coordinate in coordinate system
   double dist;          ///< [AU] apparent distance to source from observer
@@ -1445,11 +1512,11 @@ typedef struct {
  *
  * @sa NOVAS_TRACK_INIT
  */
-typedef struct {
-  novas_timespec time;     ///< The astronomical time for which the track is calculated.
-  novas_observable pos;    ///< [deg,AU,1] Apparent source position
-  novas_observable rate;   ///< [deg/s,AU/s,1/s] Apparent position rate of change
-  novas_observable accel;  ///< [deg/s<sup>2</sup>,AU/s<sup>2</sup>,1/s<sup>2</sup>] Apparent position acceleration.
+typedef struct novas_track {
+  struct novas_timespec time;     ///< The astronomical time for which the track is calculated.
+  struct novas_observable pos;    ///< [deg,AU,1] Apparent source position
+  struct novas_observable rate;   ///< [deg/s,AU/s,1/s] Apparent position rate of change
+  struct novas_observable accel;  ///< [deg/s<sup>2</sup>,AU/s<sup>2</sup>,1/s<sup>2</sup>] Apparent position acceleration.
 } novas_track;
 
 /**
@@ -1566,13 +1633,6 @@ int equ2hor(double jd_ut1, double ut1_to_tt, enum novas_accuracy accuracy, doubl
 // in system.c
 int frame_tie(const double *in, enum novas_frametie_direction direction, double *out);
 
-short precession(double jd_tdb_in, const double *in, double jd_tdb_out, double *out);
-
-int nutation(double jd_tdb, enum novas_nutation_direction direction, enum novas_accuracy accuracy, const double *in,
-        double *out);
-
-int nutation_angles(double t, enum novas_accuracy accuracy, double *restrict dpsi, double *restrict deps);
-
 short gcrs2equ(double jd_tt, enum novas_dynamical_type sys, enum novas_accuracy accuracy, double rag, double decg,
         double *restrict ra, double *restrict dec);
 
@@ -1611,6 +1671,7 @@ int e_tilt(double jd_tdb, enum novas_accuracy accuracy, double *restrict mobl, d
 short cel_pole(double jd_tt, enum novas_pole_offset_type type, double dpole1, double dpole2);
 
 // in equinox.c
+
 double ee_ct(double jd_tt_high, double jd_tt_low, enum novas_accuracy accuracy);
 
 int fund_args(double t, novas_delaunay_args *restrict a);
@@ -1623,6 +1684,13 @@ double mean_obliq(double jd_tdb);
 
 double ira_equinox(double jd_tdb, enum novas_equinox_type equinox, enum novas_accuracy accuracy);
 
+short precession(double jd_tdb_in, const double *in, double jd_tdb_out, double *out);
+
+int nutation(double jd_tdb, enum novas_nutation_direction direction, enum novas_accuracy accuracy, const double *in,
+        double *out);
+
+int nutation_angles(double t, enum novas_accuracy accuracy, double *restrict dpsi, double *restrict deps);
+
 // in earth.c
 short geo_posvel(double jd_tt, double ut1_to_tt, enum novas_accuracy accuracy, const observer *restrict obs,
         double *restrict pos, double *restrict vel);
@@ -1655,7 +1723,7 @@ short cio_basis(double jd_tdb, double ra_cio, enum novas_cio_location_type loc_t
 short cio_array(double jd_tdb, long n_pts, ra_of_cio *restrict cio);
 
 // in refract.c
-double refract(const on_surface *restrict location, enum novas_refraction_model option, double zd_obs);
+double refract(const on_surface *restrict location, enum novas_refraction_model model, double zd_obs);
 
 // in calendar.c
 double julian_date(short year, short month, short day, double hour);
@@ -1743,7 +1811,7 @@ int radec_planet(double jd_tt, const object *restrict ss_body, const observer *r
         double *restrict dis, double *restrict rv);
 
 // in refract.c
-double refract_astro(const on_surface *restrict location, enum novas_refraction_model option, double zd_astro);
+double refract_astro(const on_surface *restrict location, enum novas_refraction_model model, double zd_astro);
 
 // in observer.c
 int light_time2(double jd_tdb, const object *restrict body, const double *restrict pos_obs, double tlight0,
@@ -1913,8 +1981,6 @@ int make_redshifted_cat_entry(const char *name, double ra, double dec, double z,
 
 int make_redshifted_object(const char *name, double ra, double dec, double z, object *source);
 
-enum novas_planet novas_planet_for_name(const char *restrict name);
-
 // in grav.c
 double grav_redshift(double M_kg, double r_m);
 
@@ -1940,14 +2006,6 @@ int gcrs_to_mod(double jd_tdb, const double *in, double *out);
 
 int mod_to_gcrs(double jd_tdb, const double *in, double *out);
 
-// in orbital.c
-int novas_set_orbsys_pole(enum novas_reference_system type, double ra, double dec, novas_orbital_system *restrict sys);
-
-int make_orbital_object(const char *name, long num, const novas_orbital *orbit, object *body);
-
-int novas_orbit_posvel(double jd_tdb, const novas_orbital *restrict orbit, enum novas_accuracy accuracy,
-        double *restrict pos, double *restrict vel);
-
 
 
 // ---------------------- Added in 1.3.0 -------------------------
@@ -2020,10 +2078,6 @@ double novas_sets_below(double el, const object *restrict source, const novas_fr
 
 double novas_object_sep(const object *source1, const object *source2, const novas_frame *restrict frame);
 
-double novas_sun_angle(const object *restrict source, const novas_frame *restrict frame);
-
-double novas_moon_angle(const object *restrict source, const novas_frame *restrict frame);
-
 int novas_equ_track(const object *restrict source, const novas_frame *restrict frame, double dt, novas_track *restrict track);
 
 int novas_hor_track(const object *restrict source, const novas_frame *restrict frame, RefractionModel ref_model,
@@ -2062,6 +2116,28 @@ int novas_print_dms(double degrees, enum novas_separator_type sep, int decimals,
 novas_nutation_provider get_nutation_lp_provider();
 
 
+// ---------------------- Added in 1.4.0 -------------------------
+
+// in timescale.c
+double novas_time_gst(const novas_timespec *restrict time, enum novas_accuracy accuracy);
+
+double novas_time_lst(const novas_timespec *restrict time, double lon, enum novas_accuracy accuracy);
+
+double tt2tdb_fp(double jd_tt, double limit);
+
+double tt2tdb_hp(double jd_tt);
+
+// in refract.c
+int novas_refract_wavelength(double microns);
+
+double novas_wave_refraction(double jd_tt, const on_surface *loc, enum novas_refraction_type type, double el);
+
+// in calendar.c
+int novas_day_of_week(double tjd);
+
+int novas_day_of_year(double tjd, enum novas_calendar_type calendar, int *restrict year);
+
+
 // <================= END of SuperNOVAS API =====================>
 
 
@@ -2143,10 +2219,11 @@ int novas_error(int ret, int en, const char *restrict from, const char *restrict
  * Propagates an error (if any) with an offset. If the error is non-zero, it returns with the offset
  * error value. Otherwise it keeps going as if it weren't even there...
  *
+ * @param loc   {string} function / location from where it's called
  * @param n     {int} error code or the call that produces the error code
  * @param d     {int} offset with which the error is propagated
  *
- * @sa error_return
+ * @sa error_return()
  */
 #  define prop_error(loc, n, d) { \
   int __ret = novas_trace(loc, n, d); \
@@ -2154,6 +2231,21 @@ int novas_error(int ret, int en, const char *restrict from, const char *restrict
     return __ret; \
 }
 
+/**
+ * Returns NaN if there was an error
+ *
+ * @param loc   {string} function / location from where it's called
+ * @param n     {int} error code or the call that produces the error code
+ *
+ * @sa trace_nan()
+ */
+#  define prop_nan(loc, n) { \
+  if (n) { \
+    novas_trace_nan(loc); \
+    return NAN; \
+  } \
+}
+
 double novas_norm_ang(double angle);
 int novas_time_equals(double jd1, double jd2);
 int novas_time_equals_hp(double jd1, double jd2);
@@ -2168,6 +2260,9 @@ double novas_vdist2(const double *v1, const double *v2);
 double novas_vdot(const double *v1, const double *v2);
 
 int polar_dxdy_to_dpsideps(double jd_tt, double dx, double dy, double *restrict dpsi, double *restrict deps);
+
+int novas_frame_is_initialized(const novas_frame *frame);
+
 extern int novas_inv_max_iter;
 
 #endif /* __NOVAS_INTERNAL_API__ */
