@@ -40,8 +40,31 @@
 
 // IAU 2006 Resolution B3
 #define TC_T0      2443144.5003725       ///< 1977 January 1, 0h 0m 0s TAI
-#define TC_LB      1.550519768e-8        ///< Relative rate at which Barycentric coordinate time progresses fastern than time on Earth.
-#define TC_LG      6.969291e-10          ///< Relative rate at which Geocentric coordinate time progresses fastern than time on Earth.
+
+/**
+ * Relative rate at which Barycentric coordinate time progresses fastern than time on Earth.
+ *
+ * REFERENCES:
+ * <ol>
+ * <li>Ryan S. Park et al. 2021 AJ 161 105, DOI 10.3847/1538-3881/abd414</li>
+ * </ol>
+ */
+#define TC_LB      1.550519768e-8
+
+/**
+ * Relative rate at which Geocentric coordinate time progresses fastern than time on Earth.
+ *
+ * NOTES:
+ * <ol>
+ * <li>Updated to DE440 value (Park et al. 2021) in v1.4</li>
+ * </ol>
+ * REFERENCES:
+ * <ol>
+ * <li>Ryan S. Park et al. 2021 AJ 161 105, DOI 10.3847/1538-3881/abd414</li>
+ * </ol>
+ */
+#define TC_LG      6.969290134e-10
+
 #define TC_TDB0    (6.55e-5 / DAY)       ///< TDB time offset at TC_T0
 
 #define E9          1000000000           ///< 10<sup>9</sup> as integer
@@ -94,7 +117,7 @@ int strncasecmp(const char *s1, const char *s2, size_t n);
  *
  * REFERENCES:
  * <ol>
- * <li>Fairhead, L. & Bretagnon, P. (1990) Astron. & Astrophys. 229, 240.</li>
+ * <li>Fairhead, L. &amp; Bretagnon, P. (1990) Astron. &amp; Astrophys. 229, 240.</li>
  * <li>Kaplan, G. (2005), US Naval Observatory Circular 179.</li>
  * </ol>
  *
@@ -136,7 +159,7 @@ int tdb2tt(double jd_tdb, double *restrict jd_tt, double *restrict secdiff) {
  *
  * REFERENCES
  * <ol>
- * <li>Fairhead, L. & Bretagnon, P. (1990) Astron. & Astrophys. 229, 240.</li>
+ * <li>Fairhead, L. &amp; Bretagnon, P. (1990) Astron. &amp; Astrophys. 229, 240.</li>
  * <li>Kaplan, G. (2005), US Naval Observatory Circular 179.</li>
  * <li>Moyer, T.D. (1981), Celestial mechanics, Volume 23, Issue 1, pp. 57-68<.li>
  * </ol>
@@ -145,6 +168,8 @@ int tdb2tt(double jd_tdb, double *restrict jd_tt, double *restrict secdiff) {
  *                  can also be used here without any loss of precision on the result.
  * @return          [s] TDB - TT time difference.
  *
+ * @sa tt2tdb_hp()
+ * @sa tt2tdb_fp()
  * @sa tdb2tt()
  *
  * @since 1.0
@@ -157,6 +182,217 @@ double tt2tdb(double jd_tt) {
   return dt;
 }
 
+/**
+ * Returns the TDB-TT time difference with flexible precision. This implementation uses the series
+ * expansion by Fairhead &amp; Bretagnon 1990, terminating theterm at or below the specified
+ * limiting amplitude.
+ *
+ * REFERENCES:
+ * <ol>
+ * <li>Fairhead, L., &amp; Bretagnon, P. (1990) A&amp;A, 229, 240</li>
+ * </ol>
+ *
+ * @param jd_tt   [day] Terrestrial Time (TT) based Julian date, but Barycentric Dynamical Time (TDB)
+ * @param limit   [us] Amplitude of limiting term to include in series. 0 or negative values will
+ *                include all terms, producing the same result as `tt2tdb_hp()`.
+ * @return        [s] TDB - TT time difference.
+ *
+ * @since 1.4
+ * @author Attila Kovacs
+ *
+ * @sa tt2tdb_hp()
+ * @sa tt2tdb()
+ */
+double tt2tdb_fp(double jd_tt, double limit) {
+  static const double a[][3] = { //
+          { 1656.674564,    6283.075943033, 6.240054195 }, //
+          {   22.417471,    5753.384970095, 4.296977442 }, //
+          {   13.839792,   12566.151886066, 6.196904410 }, //
+          {    4.770086,     529.690965095, 0.444401603 }, //
+          {    4.676740,    6069.776754553, 4.021195093 }, //
+          {    2.256707,     213.299095438, 5.543113262 }, //
+          {    1.694205,      -3.523118349, 5.025132748 }, //
+          {    1.554905,   77713.772618729, 5.198467090 }, //
+          {    1.276839,    7860.419392439, 5.988822341 }, //
+          {    1.193379,    5223.693919802, 3.649823730 }, //
+          {    1.115322,    3930.209696220, 1.422745069 }, //
+          {    0.794185,   11506.769769794, 2.322313077 }, //
+          {    0.600309,    1577.343542448, 2.678271909 }, //
+          {    0.496817,    6208.294251424, 5.696701824 }, //
+          {    0.486306,    5884.926846583, 0.520007179 }, //
+          {    0.468597,    6244.942814354, 5.866398759 }, //
+          {    0.447061,      26.298319800, 3.615796498 }, //
+          {    0.435206,    -398.149003408, 4.349338347 }, //
+          {    0.432392,      74.781598567, 2.435898309 }, //
+          {    0.375510,    5507.553238667, 4.103476804 }, //
+          {    0.243085,    -775.522611324, 3.651837925 }, //
+          {    0.230685,    5856.477659115, 4.773852582 }, //
+          {    0.203747,   12036.460734888, 4.333987818 }, //
+          {    0.173435,   18849.227549974, 6.153743485 }, //
+          {    0.159080,   10977.078804699, 1.890075226 }, //
+          {    0.143935,    -796.298006816, 5.957517795 }, //
+          {    0.137927,   11790.629088659, 1.135934669 }, //
+          {    0.119979,      38.133035638, 4.551585768 }, //
+          {    0.118971,    5486.777843175, 1.914547226 }, //
+          {    0.116120,    1059.381930189, 0.873504123 }, //
+          {    0.101868,   -5573.142801634, 5.984503847 }, //
+          {    0.098358,    2544.314419883, 0.092793886 }, //
+          {    0.080164,     206.185548437, 2.095377709 }, //
+          {    0.079645,    4694.002954708, 2.949233637 }, //
+          {    0.075019,    2942.463423292, 4.980931759 }, //
+          {    0.064397,    5746.271337896, 1.280308748 }, //
+          {    0.063814,    5760.498431898, 4.167901731 }, //
+          {    0.062617,      20.775395492, 2.654394814 }, //
+          {    0.058844,     426.598190876, 4.839650148 }, //
+          {    0.054139,   17260.154654690, 3.411091093 }, //
+          {    0.048373,     155.420399434, 2.251573730 }, //
+          {    0.048042,    2146.165416475, 1.495846011 }, //
+          {    0.046551,      -0.980321068, 0.921573539 }, //
+          {    0.042732,     632.783739313, 5.720622217 }, //
+          {    0.042560,  161000.685737473, 1.270837679 }, //
+          {    0.042411,    6275.962302991, 2.869567043 }, //
+          {    0.040759,   12352.852604545, 3.981496998 }, //
+          {    0.040480,   15720.838784878, 2.546610123 }, //
+          {    0.040184,      -7.113547001, 3.565975565 }, //
+          {    0.036955,    3154.687084896, 5.071801441 }, //
+          {    0.036564,    5088.628839767, 3.324679049 }, //
+          {    0.036507,     801.820931124, 6.248866009 }, //
+          {    0.034867,     522.577418094, 5.210064075 }, //
+          {    0.033529,    9437.762934887, 2.404714239 }, //
+          {    0.033477,    6062.663207553, 4.144987272 }, //
+          {    0.032438,    6076.890301554, 0.749317412 }, //
+          {    0.032423,    8827.390269875, 5.541473556 }, //
+          {    0.030215,    7084.896781115, 3.389610345 }, //
+          {    0.029862,   12139.553509107, 1.770181024 }, //
+          {    0.029247,  -71430.695617928, 4.183178762 }, //
+          {    0.028244,   -6286.598968340, 5.069663519 }, //
+          {    0.027567,    6279.552731642, 5.040846034 }, //
+          {    0.025196,    1748.016413067, 2.901883301 }, //
+          {    0.024816,   -1194.447010225, 1.087136918 }, //
+          {    0.022567,    6133.512652857, 3.307984806 }, //
+          {    0.022509,   10447.387839604, 1.460726241 }, //
+          {    0.021691,   14143.495242431, 5.952658009 }, //
+          {    0.020937,    8429.241266467, 0.652303414 }, //
+          {    0.020322,     419.484643875, 3.735430632 }, //
+          {    0.017673,    6812.766815086, 3.186129845 }, //
+          {    0.017806,      73.297125859, 3.475975097 }, //
+          {    0.016155,   10213.285546211, 1.331103168 }, //
+          {    0.015974,   -2352.866153772, 6.145309371 }, //
+          {    0.015949,    -220.412642439, 4.005298270 }, //
+          {    0.015078,   19651.048481098, 3.969480770 }, //
+          {    0.014751,    1349.867409659, 4.308933301 }, //
+          {    0.014318,   16730.463689596, 3.016058075 }, //
+          {    0.014223,   17789.845619785, 2.104551349 }, //
+          {    0.013671,    -536.804512095, 5.971672571 }, //
+          {    0.012462,     103.092774219, 1.737438797 }, //
+          {    0.012420,    4690.479836359, 4.734090399 }, //
+          {    0.011942,    8031.092263058, 2.053414715 }, //
+          {    0.011847,    5643.178563677, 5.489005403 }, //
+          {    0.011707,   -4705.732307544, 2.654125618 }, //
+          {    0.011622,    5120.601145584, 4.863931876 }, //
+          {    0.010962,       3.590428652, 2.196567739 }, //
+          {    0.010825,     553.569402842, 0.842715011 }, //
+          {    0.010396,     951.718406251, 5.717799605 }, //
+          {    0.010453,    5863.591206116, 1.913704550 }, //
+          {    0.010099,     283.859318865, 1.942176992 }, //
+          {    0.009858,    6309.374169791, 1.061816410 }, //
+          {    0.009963,     149.563197135, 4.870690598 }, //
+          {    0.009370,  149854.400134205, 0.673880395 }, //
+          {} //
+  };
+
+  static const double b[][3] = { //
+          {  102.156724,    6283.075849991, 4.249032005 }, //
+          {    1.706807,   12566.151699983, 4.205904248 }, //
+          {    0.269668,     213.299095438, 3.400290479 }, //
+          {    0.265919,     529.690965095, 5.836047367 }, //
+          {    0.210568,      -3.523118349, 6.262738348 }, //
+          {    0.077996,    5223.693919802, 4.670344204 }, //
+          {    0.059146,      26.298319800, 1.083044735 }, //
+          {    0.054764,    1577.343542448, 4.534800170 }, //
+          {    0.034420,    -398.149003408, 5.980077351 }, //
+          {    0.033595,    5507.553238667, 5.980162321 }, //
+          {    0.032088,   18849.227549974, 4.162913471 }, //
+          {    0.029198,    5856.477659115, 0.623811863 }, //
+          {    0.027764,     155.420399434, 3.745318113 }, //
+          {    0.025190,    5746.271337896, 2.980330535 }, //
+          {    0.024976,    5760.498431898, 2.467913690 }, //
+          {    0.022997,    -796.298006816, 1.174411803 }, //
+          {    0.021774,     206.185548437, 3.854787540 }, //
+          {    0.017925,    -775.522611324, 1.092065955 }, //
+          {    0.013794,     426.598190876, 2.699831988 }, //
+          {    0.013276,    6062.663207553, 5.845801920 }, //
+          {    0.012869,    6076.890301554, 5.333425680 }, //
+          {    0.012152,    1059.381930189, 6.222874454 }, //
+          {    0.011774,   12036.460734888, 2.292832062 }, //
+          {    0.011081,      -7.113547001, 5.154724984 }, //
+          {    0.010143,    4694.002954708, 4.044013795 }, //
+          {    0.010084,     522.577418094, 0.749320262 }, //
+          {    0.009357,    5486.777843175, 3.416081409 }, //
+          {} //
+  };
+
+  static const double c[][3] = { //
+          {    0.370115,       0.000000000, 4.712388980 }, //
+          {    4.322990,    6283.075849991, 2.642893748 }, //
+          {    0.122605,   12566.151699983, 2.438140634 }, //
+          {    0.019476,     213.299095438, 1.642186981 }, //
+          {    0.016916,     529.690965095, 4.510959344 }, //
+          {    0.013374,      -3.523118349, 1.502210314 }, //
+          {} //
+  };
+
+  static const double d[3] = { 0.143388, 6283.075849991, 1.131453581 };
+
+  const double t = (jd_tt - NOVAS_JD_J2000) / (10.0 * JULIAN_CENTURY_DAYS);
+  const double t2 = t * t;
+
+  double us = 0.0;
+  int i;
+
+  if(limit < 0.0)
+    limit = 0.0;
+
+  for(i = 0; a[i][0] > limit; i ++)
+    us += a[i][0] * sin(a[i][1] * t + a[i][2]);
+
+  limit *= fabs(t);
+  for(i = 0; b[i][0] > limit; i ++)
+    us += b[i][0] * t * sin(b[i][1] * t + b[i][2]);
+
+  limit *= fabs(t);
+  for(i = 0; c[i][0] > limit; i ++)
+    us += c[i][0] * t2 * sin(c[i][1] * t + c[i][2]);
+
+  limit *= fabs(t);
+  if(d[0] > limit)
+    us += d[0] * t2 * t * sin(d[1] * t + d[2]);
+
+  return 1e-6 * us;
+}
+
+/**
+ * Returns the TDB-TT time difference with flexible precision. This implementation uses the full
+ * series expansion by Fairhead &amp; Bretagnon 1990, resulting in an accuracy below 100 ns.
+ *
+ * REFERENCES:
+ * <ol>
+ * <li>Fairhead, L., &amp; Bretagnon, P. (1990) A&amp;A, 229, 240</li>
+ * </ol>
+ *
+ * @param jd_tt   [day] Terrestrial Time (TT) based Julian date, but Barycentric Dynamical Time (TDB)
+ * @return        [s] TDB - TT time difference.
+ *
+ * @since 1.4
+ * @author Attila Kovacs
+ *
+ * @sa tt2tdb_fp()
+ * @sa tt2tdb()
+ */
+double tt2tdb_hp(double jd_tt) {
+  return tt2tdb_fp(jd_tt, 0.0);
+}
+
 /**
  * Returns the difference between Terrestrial Time (TT) and Universal Coordinated Time (UTC)
  *
@@ -244,7 +480,7 @@ int novas_set_time(enum novas_timescale timescale, double jd, int leap, double d
  * <li>IAU 1991, RECOMMENDATION III. XXIst General Assembly of the
  * International Astronomical Union. Retrieved 6 June 2019.</li>
  * <li>IAU 2006 resolution 3, see Recommendation and footnotes, note 3.</li>
- * <li>Fairhead, L. & Bretagnon, P. (1990) Astron. & Astrophys. 229, 240.</li>
+ * <li>Fairhead, L. &amp; Bretagnon, P. (1990) Astron. &amp; Astrophys. 229, 240.</li>
  * <li>Kaplan, G. (2005), US Naval Observatory Circular 179.</li>
  * <li><a href="https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/FORTRAN/req/time.html#The%20Relationship%20between%20TT%20and%20TDB">
  * https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/FORTRAN/req/time.html</a></li>
@@ -399,7 +635,7 @@ double novas_get_time(const novas_timespec *restrict time, enum novas_timescale
  * <li>IAU 1991, RECOMMENDATION III. XXIst General Assembly of the
  * International Astronomical Union. Retrieved 6 June 2019.</li>
  * <li>IAU 2006 resolution 3, see Recommendation and footnotes, note 3.</li>
- * <li>Fairhead, L. & Bretagnon, P. (1990) Astron. & Astrophys. 229, 240.</li>
+ * <li>Fairhead, L. &amp; Bretagnon, P. (1990) Astron. &amp; Astrophys. 229, 240.</li>
  * <li>Kaplan, G. (2005), US Naval Observatory Circular 179.</li>
  * <li><a href="https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/FORTRAN/req/time.html#The%20Relationship%20between%20TT%20and%20TDB">
  * https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/FORTRAN/req/time.html</a></li>
@@ -1046,7 +1282,7 @@ double novas_date_scale(const char *restrict date, enum novas_timescale *restric
 
 static int timestamp(long ijd, double fjd, enum novas_calendar_type cal, char *buf) {
   long dd, ms;
-  int y, M, d, h, m, s;
+  int y = 0, M = 0, d = 0, h, m, s;
 
   // fjd -> [-0.5:0.5) range
   dd = (long) floor(fjd + 0.5);
@@ -1366,4 +1602,58 @@ enum novas_timescale novas_parse_timescale(const char *restrict str, char **rest
   return scale;
 }
 
+/**
+ * Returns the Greenwich (apparent) Sidereal Time (GST/GaST) for a given astronomical time specification.
+ * If you need mean sidereal time (GMST), you should use sidereal_time() instead.
+ *
+ * @param time      The astronomoical time specification.
+ * @param accuracy  NOVAS_FULL_ACCURACY (0) or NOVAS_REDUCED_ACCURACY (1).
+ * @return          [h] The Greenwich apparent Sidereal Time (GST / GaST) in the [0:24) hour range, or else
+ *                  NAN if there was an error (`errno` will indicate the type of error).
+ *
+ * @since 1.4
+ * @author Attila Kovacs
+ *
+ * @sa novas_time_lst()
+ * @sa sidereal_time()
+ * @sa novas_set_time()
+ */
+double novas_time_gst(const novas_timespec *restrict time, enum novas_accuracy accuracy) {
+  const char *fn = "novas_time_gst";
 
+  double fjd_ut1, gst = NAN;
+  long ijd_ut1 = 0L;
+
+  fjd_ut1 = novas_get_split_time(time, NOVAS_UT1, &ijd_ut1);
+  if(isnan(fjd_ut1))
+    return novas_trace_nan(fn);
+
+  if(sidereal_time(ijd_ut1, fjd_ut1, time->ut1_to_tt, NOVAS_TRUE_EQUINOX, EROT_ERA, accuracy, &gst) != 0)
+    return novas_trace_nan(fn);
+
+  return gst;
+}
+
+/**
+ * Returns the Local (apparent) Sidereal Time (LST/LaST) for a given astronomical time specification and
+ * observer location.
+ *
+ * @param time      The astronomoical time specification.
+ * @param lon       [deg] The geodetic longitude of the observer.
+ * @param accuracy  NOVAS_FULL_ACCURACY (0) or NOVAS_REDUCED_ACCURACY (1).
+ * @return          [h] The Local apparent Sidereal Time (LST / LaST) in the [0:24) hour range, or else
+ *                  NAN if there was an error (`errno` will indicate the type of error).
+ *
+ * @since 1.4
+ * @author Attila Kovacs
+ *
+ * @sa novas_frame_lst()
+ * @sa novas_set_time()
+ */
+double novas_time_lst(const novas_timespec *restrict time, double lon, enum novas_accuracy accuracy) {
+  double st = novas_time_gst(time, accuracy);
+  if(isnan(st))
+    return novas_trace_nan("novas_time_lst");
+  st = remainder(st + lon / 15.0, DAY_HOURS);
+  return st < 0.0 ? st + DAY_HOURS : st;
+}
